@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,12 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
+
+from google.protobuf import duration_pb2  # type: ignore
 import proto  # type: ignore
 
-from google.cloud.run_v2.types import k8s_min
-from google.cloud.run_v2.types import vendor_settings
-from google.protobuf import duration_pb2  # type: ignore
-
+from google.cloud.run_v2.types import k8s_min, vendor_settings
 
 __protobuf__ = proto.module(
     package="google.cloud.run.v2",
@@ -37,10 +39,37 @@ class RevisionTemplate(proto.Message):
             The unique name for the revision. If this
             field is omitted, it will be automatically
             generated based on the Service name.
-        labels (Mapping[str, str]):
-            KRM-style labels for the resource.
-        annotations (Mapping[str, str]):
-            KRM-style annotations for the resource.
+        labels (MutableMapping[str, str]):
+            Unstructured key value map that can be used to organize and
+            categorize objects. User-provided labels are shared with
+            Google's billing system, so they can be used to filter, or
+            break down billing charges by team, component, environment,
+            state, etc. For more information, visit
+            https://cloud.google.com/resource-manager/docs/creating-managing-labels
+            or https://cloud.google.com/run/docs/configuring/labels.
+
+            .. raw:: html
+
+                <p>Cloud Run API v2 does not support labels with `run.googleapis.com`,
+                `cloud.googleapis.com`, `serving.knative.dev`, or `autoscaling.knative.dev`
+                namespaces, and they will be rejected. All system labels in v1 now have a
+                corresponding field in v2 RevisionTemplate.
+        annotations (MutableMapping[str, str]):
+            Unstructured key value map that may be set by external tools
+            to store and arbitrary metadata. They are not queryable and
+            should be preserved when modifying objects.
+
+            .. raw:: html
+
+                <p>Cloud Run API v2 does not support annotations with `run.googleapis.com`,
+                `cloud.googleapis.com`, `serving.knative.dev`, or `autoscaling.knative.dev`
+                namespaces, and they will be rejected. All system annotations in v1 now
+                have a corresponding field in v2 RevisionTemplate.
+
+            .. raw:: html
+
+                <p>This field follows Kubernetes annotations' namespacing, limits, and
+                rules.
         scaling (google.cloud.run_v2.types.RevisionScaling):
             Scaling settings for this Revision.
         vpc_access (google.cloud.run_v2.types.VpcAccess):
@@ -58,10 +87,10 @@ class RevisionTemplate(proto.Message):
             permissions the revision has. If not provided,
             the revision will use the project's default
             service account.
-        containers (Sequence[google.cloud.run_v2.types.Container]):
+        containers (MutableSequence[google.cloud.run_v2.types.Container]):
             Holds the single container that defines the
             unit of execution for this Revision.
-        volumes (Sequence[google.cloud.run_v2.types.Volume]):
+        volumes (MutableSequence[google.cloud.run_v2.types.Volume]):
             A list of Volumes to make available to
             containers.
         execution_environment (google.cloud.run_v2.types.ExecutionEnvironment):
@@ -75,64 +104,70 @@ class RevisionTemplate(proto.Message):
         max_instance_request_concurrency (int):
             Sets the maximum number of requests that each
             serving instance can receive.
+        session_affinity (bool):
+            Enable session affinity.
     """
 
-    revision = proto.Field(
+    revision: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=2,
     )
-    annotations = proto.MapField(
+    annotations: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=3,
     )
-    scaling = proto.Field(
+    scaling: vendor_settings.RevisionScaling = proto.Field(
         proto.MESSAGE,
         number=4,
         message=vendor_settings.RevisionScaling,
     )
-    vpc_access = proto.Field(
+    vpc_access: vendor_settings.VpcAccess = proto.Field(
         proto.MESSAGE,
         number=6,
         message=vendor_settings.VpcAccess,
     )
-    timeout = proto.Field(
+    timeout: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=8,
         message=duration_pb2.Duration,
     )
-    service_account = proto.Field(
+    service_account: str = proto.Field(
         proto.STRING,
         number=9,
     )
-    containers = proto.RepeatedField(
+    containers: MutableSequence[k8s_min.Container] = proto.RepeatedField(
         proto.MESSAGE,
         number=10,
         message=k8s_min.Container,
     )
-    volumes = proto.RepeatedField(
+    volumes: MutableSequence[k8s_min.Volume] = proto.RepeatedField(
         proto.MESSAGE,
         number=11,
         message=k8s_min.Volume,
     )
-    execution_environment = proto.Field(
+    execution_environment: vendor_settings.ExecutionEnvironment = proto.Field(
         proto.ENUM,
         number=13,
         enum=vendor_settings.ExecutionEnvironment,
     )
-    encryption_key = proto.Field(
+    encryption_key: str = proto.Field(
         proto.STRING,
         number=14,
     )
-    max_instance_request_concurrency = proto.Field(
+    max_instance_request_concurrency: int = proto.Field(
         proto.INT32,
         number=15,
     )
+    session_affinity: bool = proto.Field(
+        proto.BOOL,
+        number=19,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
